@@ -1,6 +1,6 @@
 package MooseX::Iterator;
 
-our $VERSION   = '0.08';
+our $VERSION   = '0.09';
 our $AUTHORITY = 'cpan:RLB';
 
 use MooseX::Iterator::Array;
@@ -30,7 +30,7 @@ Access the Iterator directly:
     while ( $iter->has_next ) {
         print $iter->next;
     }
-    
+
 Or use the meta class:
 
     package TestIterator;
@@ -58,7 +58,7 @@ Or use the meta class:
 
     my $iter = $test->iter;
 
-    while ( $it->has_next ) {
+    while ( $iter->has_next ) {
         my $next = $iter->next;
         print $next->{'key'}   . "\n";
         print $next->{'value'} . "\n";
@@ -89,12 +89,24 @@ The peek method returns the next item without moving the state of the iterator f
 
 =back
 
+=item Subclassing MooseX::Iterator::Meta::Iterable
+
+When subclassing MooseX::Iterator::Meta::Iterable for your own iterators override MooseX::Iterator::Meta::Iterable::_calculate_iterator_class_for_type to
+returns the name of the class that iterates over your new collection type. The class must implement the MooseX::Iterator::Role role.
+
+=back
+
 =head1 AUTHOR
 
 Robert Boone E<lt>rlb@cpan.orgE<gt>
 
 And thank you to Steven Little (steven) and Matt Trout (mst) for the help and advice they gave.
 
+=head1 Code Repository
+
+ Git - http://github.com/rlb3/moosex-iterator/tree/master
+ SVN - http://code2.0beta.co.uk/moose/svn/MooseX-Iterator/trunk/
+
 =head1 COPYRIGHT AND LICENSE
 
 This library is free software; you can redistribute it and/or modify
